Index: trunk/MagicSoft/Mars/mbase/MReadTree.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MReadTree.cc	(revision 756)
+++ trunk/MagicSoft/Mars/mbase/MReadTree.cc	(revision 757)
@@ -347,4 +347,8 @@
 // corresponding object won't be created automatically)
 //
+// This functionality is for experienced users which don't want to
+// read in branches which are not processed in the program (for
+// speed reasons)
+//
 void MReadTree::VetoBranch(const char *name)
 {
Index: trunk/MagicSoft/Mars/mbase/MReadTree.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MReadTree.h	(revision 756)
+++ trunk/MagicSoft/Mars/mbase/MReadTree.h	(revision 757)
@@ -8,13 +8,18 @@
 class TFile;
 class TChain;
+class TArrayC;
 
 class MReadTree : public MTask
 {
 private:
-    TFile  *fFile;       // Pointer to file
-    TChain *fChain;      // Pointer to tree
+    TFile   *fFile;       // Pointer to file
+    TChain  *fChain;      // Pointer to tree
 
-    UInt_t  fNumEntry;   // Number of actual entry
-    UInt_t  fNumEntries; // Number of Events in Tree
+    TArrayC *fVetoList;   // List of Branches which are not allowed to get enabled
+
+    UInt_t   fNumEntry;   // Number of actual entry
+    UInt_t   fNumEntries; // Number of Events in Tree
+
+    Bool_t HasVeto(const char *name) const;
 
 public:
@@ -27,6 +32,7 @@
 
     void AddFile(const char *fname);
+    void VetoBranch(const char *name);
 
-    Bool_t GetEvent() ; 
+    Bool_t GetEvent();
 
     Bool_t DecEventNum(UInt_t dec=1); // decrease number of event (position in tree)
